@@ -22,7 +22,6 @@ import collections
 import logging
 from operator import attrgetter
 
-from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
 from novaclient import api_versions
@@ -46,114 +45,6 @@ INSTANCE_ACTIVE_STATE = 'ACTIVE'
 VOLUME_STATE_AVAILABLE = "available"
 DEFAULT_QUOTA_NAME = 'default'
 
-# python-novaclient 16.0.0 removed the list_extensions module and the
-# GET /extensions API is deprecated since Newton. Furthermore, the ability
-# to enable/disable compute API extensions was also removed in Newton.
-# Therefore we hard-code the list of extensions here until the
-# OPENSTACK_NOVA_EXTENSIONS_BLACKLIST setting is no longer used.
-EXTENSIONS = (
-    'AccessIPs',
-    'AdminActions',
-    'AdminPassword',
-    'Agents',
-    'Aggregates',
-    'AssistedVolumeSnapshots',
-    'AttachInterfaces',
-    'AvailabilityZone',
-    'BareMetalExtStatus',
-    'BareMetalNodes',
-    'BlockDeviceMapping',
-    'BlockDeviceMappingV2Boot',
-    'CellCapacities',
-    'Cells',
-    'Certificates',
-    'Cloudpipe',
-    'CloudpipeUpdate',
-    'ConfigDrive',
-    'ConsoleAuthTokens',
-    'ConsoleOutput',
-    'Consoles',
-    'CreateBackup',
-    'Createserverext',
-    'DeferredDelete',
-    'DiskConfig',
-    'Evacuate',
-    'ExtendedAvailabilityZone',
-    'ExtendedEvacuateFindHost',
-    'ExtendedFloatingIps',
-    'ExtendedHypervisors',
-    'ExtendedIps',
-    'ExtendedIpsMac',
-    'ExtendedNetworks',
-    'ExtendedQuotas',
-    'ExtendedRescueWithImage',
-    'ExtendedServerAttributes',
-    'ExtendedServices',
-    'ExtendedServicesDelete',
-    'ExtendedStatus',
-    'ExtendedStatus',
-    'ExtendedVolumes',
-    'FixedIPs',
-    'FlavorAccess',
-    'FlavorDisabled',
-    'FlavorExtraData',
-    'FlavorExtraSpecs',
-    'FlavorManage',
-    'FlavorRxtx',
-    'FlavorSwap',
-    'FloatingIpDns',
-    'FloatingIpPools',
-    'FloatingIps',
-    'FloatingIpsBulk',
-    'Fping',
-    'HideServerAddresses',
-    'Hosts',
-    'HypervisorStatus',
-    'Hypervisors',
-    'ImageSize',
-    'InstanceActions',
-    'Keypairs',
-    'LockServer',
-    'MigrateServer',
-    'Migrations',
-    'Multinic',
-    'MultipleCreate',
-    'NetworkAssociationSupport',
-    'Networks',
-    'OSInstanceUsageAuditLog',
-    'OSTenantNetworks',
-    'PauseServer',
-    'Personality',
-    'PreserveEphemeralOnRebuild',
-    'QuotaClasses',
-    'Quotas',
-    'Rescue',
-    'SchedulerHints',
-    'SecurityGroupDefaultRules',
-    'SecurityGroups',
-    'ServerDiagnostics',
-    'ServerExternalEvents',
-    'ServerGroupQuotas',
-    'ServerGroups',
-    'ServerListMultiStatus',
-    'ServerPassword',
-    'ServerSortKeys',
-    'ServerStartStop',
-    'ServerUsage',
-    'Services',
-    'Shelve',
-    'SimpleTenantUsage',
-    'SuspendServer',
-    'UsedLimits',
-    'UsedLimitsForAdmin',
-    'UserData',
-    'UserQuotas',
-    'VirtualInterfaces',
-    'VolumeAttachmentUpdate',
-    'Volumes'
-)
-
-
 get_microversion = _nova.get_microversion
 server_get = _nova.server_get
 Server = _nova.Server
@@ -1065,8 +956,7 @@ def service_disable(request, host, binary, reason=None):
     if reason:
         return _nova.novaclient(request).services.disable_log_reason(
             host, binary, reason)
-    else:
-        return _nova.novaclient(request).services.disable(host, binary)
+    return _nova.novaclient(request).services.disable(host, binary)
 
 
 @profiler.trace
@@ -1126,27 +1016,6 @@ def interface_detach(request, server, port_id):
     return _nova.novaclient(request).servers.interface_detach(server, port_id)
 
 
-@profiler.trace
-@memoized.memoized
-def list_extensions(request):
-    """List all nova extension names, except the ones in the blacklist."""
-    blacklist = set(settings.OPENSTACK_NOVA_EXTENSIONS_BLACKLIST)
-    return tuple(
-        extension for extension in EXTENSIONS if extension not in blacklist
-    )
-
-
-@profiler.trace
-@memoized.memoized
-def extension_supported(extension_name, request):
-    """Determine if nova supports a given extension name.
-
-    Example values for the extension_name include AdminActions, ConsoleOutput,
-    etc.
-    """
-    return extension_name in list_extensions(request)
-
-
 @profiler.trace
 def can_set_server_password():
     return utils.get_dict_config('OPENSTACK_HYPERVISOR_FEATURES',
