@@ -17,7 +17,6 @@ import logging
 
 from django.conf import settings
 from django import http
-from django.utils import decorators
 
 from oslo_serialization import jsonutils
 
@@ -29,7 +28,7 @@ LOG = logging.getLogger(__name__)
 class AjaxError(Exception):
     def __init__(self, http_status, msg):
         self.http_status = http_status
-        super(AjaxError, self).__init__(msg)
+        super().__init__(msg)
 
 
 http_errors = exceptions.UNAUTHORIZED + exceptions.NOT_FOUND + \
@@ -53,8 +52,8 @@ class CreatedResponse(_RestResponse):
         else:
             content = ''
             content_type = None
-        super(CreatedResponse, self).__init__(status=201, content=content,
-                                              content_type=content_type)
+        super().__init__(status=201, content=content,
+                         content_type=content_type)
         self['Location'] = location
 
 
@@ -66,7 +65,7 @@ class JSONResponse(_RestResponse):
             content = jsonutils.dumps(data, sort_keys=settings.DEBUG,
                                       cls=json_encoder)
 
-        super(JSONResponse, self).__init__(
+        super().__init__(
             status=status,
             content=content,
             content_type='application/json',
@@ -104,7 +103,7 @@ def ajax(authenticated=True, data_required=False,
     def decorator(function, authenticated=authenticated,
                   data_required=data_required):
         @functools.wraps(function,
-                         assigned=decorators.available_attrs(function))
+                         assigned=functools.WRAPPER_ASSIGNMENTS)
         def _wrapped(self, request, *args, **kw):
             if authenticated and not request.user.is_authenticated:
                 return JSONResponse('not logged in', 401)
@@ -128,7 +127,7 @@ def ajax(authenticated=True, data_required=False,
                 data = function(self, request, *args, **kw)
                 if isinstance(data, http.HttpResponse):
                     return data
-                elif data is None:
+                if data is None:
                     return JSONResponse('', status=204)
                 return JSONResponse(data, json_encoder=json_encoder)
             except http_errors as e:
