@@ -17,7 +17,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import settings
 from django.urls import reverse
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
@@ -38,6 +37,7 @@ from openstack_dashboard.dashboards.project.instances import views
 from openstack_dashboard.dashboards.project.instances.workflows \
     import update_instance
 from openstack_dashboard.utils import futurist_utils
+from openstack_dashboard.utils import settings as setting_utils
 
 
 # re-use console from project.instances.views to make reflection work
@@ -93,21 +93,35 @@ class AdminIndexView(tables.PagedTableMixin, tables.DataTableView):
             exceptions.handle(self.request, msg)
             return {}
 
-    def _get_images(self, instances=()):
+    def _get_images(self):
         # Gather our images to correlate our instances to them
         try:
-            # NOTE(aarefiev): request images, instances was booted from.
-            img_ids = (instance.image.get('id') for instance in
-                       instances if isinstance(instance.image, dict))
-            real_img_ids = list(filter(None, img_ids))
-            images = api.glance.image_list_detailed_by_ids(
-                self.request, real_img_ids)
-            image_map = dict((image.id, image) for image in images)
+            # Community images have to be retrieved separately and merged,
+            # because their visibility has to be explicitly defined in the
+            # API call and the Glance API currently does not support filtering
+            # by multiple values in the visibility field.
+            # TODO(gabriel): Handle pagination.
+            images = api.glance.image_list_detailed(self.request)[0]
+            community_images = api.glance.image_list_detailed(
+                self.request, filters={'visibility': 'community'})[0]
+            image_map = {
+                image.id: image for image in images
+            }
+            # Images have to be filtered by their uuids; some users
+            # have default access to certain community images.
+            for image in community_images:
+                image_map.setdefault(image.id, image)
             return image_map
         except Exception:
             exceptions.handle(self.request, ignore=True)
             return {}
 
+    def _get_images_by_name(self, image_name):
+        result = api.glance.image_list_detailed(
+            self.request, filters={'name': image_name})
+        images = result[0]
+        return dict((image.id, image) for image in images)
+
     def _get_flavors(self):
         # Gather our flavors to correlate against IDs
         try:
@@ -131,6 +145,15 @@ class AdminIndexView(tables.PagedTableMixin, tables.DataTableView):
                               _('Unable to retrieve instance list.'))
         return instances
 
+    def _get_volumes(self):
+        # Gather our volumes to get their image metadata for instance
+        try:
+            volumes = api.cinder.volume_list(self.request)
+            return dict((str(volume.id), volume) for volume in volumes)
+        except Exception:
+            exceptions.handle(self.request, ignore=True)
+            return {}
+
     def get_data(self):
         marker, sort_dir = self._get_marker()
         default_search_opts = {'marker': marker,
@@ -142,8 +165,8 @@ class AdminIndexView(tables.PagedTableMixin, tables.DataTableView):
         # If filter_first is set and if there are not other filters
         # selected, then search criteria must be provided and return an empty
         # list
-        filter_first = getattr(settings, 'FILTER_DATA_FIRST', {})
-        if (filter_first.get('admin.instances', False) and
+        if (setting_utils.get_dict_config('FILTER_DATA_FIRST',
+                                          'admin.instances') and
                 len(search_opts) == len(default_search_opts)):
             self._needs_filter_first = True
             self._more = False
@@ -151,24 +174,37 @@ class AdminIndexView(tables.PagedTableMixin, tables.DataTableView):
 
         self._needs_filter_first = False
 
-        instances = self._get_instances(search_opts, sort_dir)
         results = futurist_utils.call_functions_parallel(
-            (self._get_images, [tuple(instances)]),
+            self._get_images,
+            self._get_volumes,
             self._get_flavors,
             self._get_tenants)
-        image_dict, flavor_dict, tenant_dict = results
+        image_dict, volume_dict, flavor_dict, tenant_dict = results
 
-        non_api_filter_info = (
+        non_api_filter_info = [
             ('project', 'tenant_id', tenant_dict.values()),
-            ('image_name', 'image', image_dict.values()),
             ('flavor_name', 'flavor', flavor_dict.values()),
-        )
+        ]
+
+        filter_by_image_name = 'image_name' in search_opts
+        if filter_by_image_name:
+            image_dict = self._get_images_by_name(search_opts['image_name'])
+            non_api_filter_info.append(
+                ('image_name', 'image', image_dict.values())
+            )
+
         if not views.process_non_api_filters(search_opts, non_api_filter_info):
             self._more = False
             return []
 
+        instances = self._get_instances(search_opts, sort_dir)
+
+        if not filter_by_image_name:
+            image_dict = self._get_images()
+
         # Loop through instances to get image, flavor and tenant info.
         for inst in instances:
+            self._populate_image_info(inst, image_dict, volume_dict)
             if hasattr(inst, 'image') and isinstance(inst.image, dict):
                 image_id = inst.image.get('id')
                 if image_id in image_dict:
@@ -195,6 +231,49 @@ class AdminIndexView(tables.PagedTableMixin, tables.DataTableView):
             inst.tenant_name = getattr(tenant, "name", None)
         return instances
 
+    def _populate_image_info(self, instance, image_dict, volume_dict):
+        if not hasattr(instance, 'image'):
+            return
+        # Instance from image returns dict
+        if isinstance(instance.image, dict):
+            image_id = instance.image.get('id')
+            if image_id in image_dict:
+                instance.image = image_dict[image_id]
+            # In case image not found in image_dict, set name to empty
+            # to avoid fallback API call to Glance in api/nova.py
+            # until the call is deprecated in api itself
+            else:
+                instance.image['name'] = _("-")
+        # Otherwise trying to get image from volume metadata
+        else:
+            instance_volumes = [
+                attachment
+                for volume in volume_dict.values()
+                for attachment in volume.attachments
+                if attachment['server_id'] == instance.id
+            ]
+            # While instance from volume is being created,
+            # it does not have volumes
+            if not instance_volumes:
+                return
+            # Sorting attached volumes by device name (eg '/dev/sda')
+            instance_volumes.sort(key=lambda attach: attach['device'])
+            # Getting volume object, which is as attached
+            # as the first device
+            boot_volume = volume_dict[instance_volumes[0]['id']]
+            # There is a case where volume_image_metadata contains
+            # only fields other than 'image_id' (See bug 1834747),
+            # so we try to populate image information only when it is found.
+            volume_metadata = getattr(boot_volume, "volume_image_metadata", {})
+            image_id = volume_metadata.get('image_id')
+            if image_id:
+                try:
+                    instance.image = image_dict[image_id].to_dict()
+                except KeyError:
+                    # KeyError occurs when volume was created from image and
+                    # then this image is deleted.
+                    pass
+
 
 class LiveMigrateView(forms.ModalFormView):
     form_class = project_forms.LiveMigrateForm
@@ -205,7 +284,7 @@ class LiveMigrateView(forms.ModalFormView):
     success_label = page_title
 
     def get_context_data(self, **kwargs):
-        context = super(LiveMigrateView, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         context["instance_id"] = self.kwargs['instance_id']
         return context
 
@@ -231,7 +310,7 @@ class LiveMigrateView(forms.ModalFormView):
             exceptions.handle(self.request, msg, redirect=redirect)
 
     def get_initial(self):
-        initial = super(LiveMigrateView, self).get_initial()
+        initial = super().get_initial()
         _object = self.get_object()
         if _object:
             current_host = getattr(_object, 'OS-EXT-SRV-ATTR:host', '')
