@@ -89,6 +89,7 @@ class RoleAssignmentsTab(tabs.TableTab):
     slug = "roleassignments"
     template_name = "horizon/common/_detail_table.html"
     preload = False
+    policy_rules = (("identity", "identity:list_role_assignments"),)
 
     def get_roleassignmentstable_data(self):
         user = self.tab_group.kwargs['user']
@@ -135,6 +136,7 @@ class GroupsTab(tabs.TableTab):
     slug = "groups"
     template_name = "horizon/common/_detail_table.html"
     preload = False
+    policy_rules = (("identity", "identity:list_groups"),)
 
     def get_groupstable_data(self):
         user_groups = []
