@@ -109,6 +109,7 @@ class RestoreBackupForm(forms.SelfHandlingForm):
                                           required=False)
     backup_id = forms.CharField(widget=forms.HiddenInput())
     backup_name = forms.CharField(widget=forms.HiddenInput())
+    redirect_url = 'horizon:project:backups:index'
 
     def __init__(self, request, *args, **kwargs):
         super().__init__(request, *args, **kwargs)
@@ -118,7 +119,7 @@ class RestoreBackupForm(forms.SelfHandlingForm):
             volumes = api.cinder.volume_list(request, search_opts)
         except Exception:
             msg = _('Unable to lookup volume or backup information.')
-            redirect = reverse('horizon:project:backups:index')
+            redirect = reverse(self.redirect_url)
             exceptions.handle(request, msg, redirect=redirect)
             raise exceptions.Http302(redirect)
 
@@ -148,5 +149,5 @@ class RestoreBackupForm(forms.SelfHandlingForm):
             return restore
         except Exception:
             msg = _('Unable to restore backup.')
-            redirect = reverse('horizon:project:backups:index')
+            redirect = reverse(self.redirect_url)
             exceptions.handle(request, msg, redirect=redirect)
