@@ -19,9 +19,9 @@
 import json
 
 from django.conf import settings
-from django.core.urlresolvers import reverse
-from django.core.urlresolvers import reverse_lazy
 from django.http import HttpResponse
+from django.urls import reverse
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 from django.views.generic import View
 
@@ -75,6 +75,8 @@ from openstack_dashboard.dashboards.project.routers.tables import \
     STATUS_DISPLAY_CHOICES as routers_status_choices
 from openstack_dashboard.dashboards.project.routers import\
     views as r_views
+from openstack_dashboard import policy
+from openstack_dashboard.utils import settings as setting_utils
 
 # List of known server statuses that wont connect to the console
 console_invalid_status = {
@@ -113,7 +115,7 @@ class NTAddInterfaceView(p_views.AddInterfaceView):
         return reverse("horizon:project:network_topology:index")
 
     def get_context_data(self, **kwargs):
-        context = super(NTAddInterfaceView, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         context['form_url'] = 'horizon:project:network_topology:interface'
         return context
 
@@ -204,7 +206,7 @@ class NetworkTopologyView(tabs.TabView):
     page_title = _("Network Topology")
 
     def get_context_data(self, **kwargs):
-        context = super(NetworkTopologyView, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         return utils.get_context(self.request, context)
 
 
@@ -213,21 +215,21 @@ class JSONView(View):
 
     @property
     def is_router_enabled(self):
-        network_config = getattr(settings, 'OPENSTACK_NEUTRON_NETWORK', {})
-        return network_config.get('enable_router', True)
+        return setting_utils.get_dict_config('OPENSTACK_NEUTRON_NETWORK',
+                                             'enable_router')
 
     def add_resource_url(self, view, resources):
         tenant_id = self.request.user.tenant_id
         for resource in resources:
-            if (resource.get('tenant_id')
-                    and tenant_id != resource.get('tenant_id')):
+            if (resource.get('tenant_id') and
+                    tenant_id != resource.get('tenant_id')):
                 continue
             resource['url'] = reverse(view, None, [str(resource['id'])])
 
     def _check_router_external_port(self, ports, router_id, network_id):
         for port in ports:
-            if (port['network_id'] == network_id
-                    and port['device_id'] == router_id):
+            if (port['network_id'] == network_id and
+                    port['device_id'] == router_id):
                 return True
         return False
 
@@ -238,7 +240,7 @@ class JSONView(View):
         except Exception:
             servers = []
         data = []
-        console_type = getattr(settings, 'CONSOLE_TYPE', 'AUTO')
+        console_type = settings.CONSOLE_TYPE
         # lowercase of the keys will be used at the end of the console URL.
         for server in servers:
             server_data = {'name': server.name,
@@ -263,19 +265,34 @@ class JSONView(View):
         # specify tenant_id for subnet. The subnet which belongs to the public
         # network is needed to draw subnet information on public network.
         try:
+            # NOTE(amotoki):
+            # To support auto allocated network in the network topology view,
+            # we need to handle the auto allocated network which haven't been
+            # created yet. The current network topology logic cannot not handle
+            # fake network ID properly, so we temporarily exclude
+            # pre-auto-allocated-network from the network topology view.
+            # It would be nice if someone is interested in supporting it.
             neutron_networks = api.neutron.network_list_for_tenant(
                 request,
-                request.user.tenant_id)
+                request.user.tenant_id,
+                include_pre_auto_allocate=False)
         except Exception:
             neutron_networks = []
         networks = []
         for network in neutron_networks:
+            allow_delete_subnet = policy.check(
+                (("network", "delete_subnet"),),
+                request,
+                target={'network:tenant_id': getattr(network,
+                                                     'tenant_id', None)}
+            )
             obj = {'name': network.name_or_id,
                    'id': network.id,
                    'subnets': [{'id': subnet.id,
                                 'cidr': subnet.cidr}
                                for subnet in network.subnets],
                    'status': self.trans.network[network.status],
+                   'allow_delete_subnet': allow_delete_subnet,
                    'original_status': network.status,
                    'router:external': network['router:external']}
             self.add_resource_url('horizon:project:networks:subnets:detail',
@@ -353,8 +370,8 @@ class JSONView(View):
                   'status': self.trans.port[port.status],
                   'original_status': port.status}
                  for port in neutron_ports
-                 if port.device_owner != 'network:router_ha_interface'
-                 and port.network_id in tenant_network_ids]
+                 if (port.device_owner != 'network:router_ha_interface' and
+                     port.network_id in tenant_network_ids)]
         self.add_resource_url('horizon:project:networks:ports:detail',
                               ports)
         return ports
