@@ -34,13 +34,15 @@ LOG = logging.getLogger(__name__)
 
 class UpdateNetwork(forms.SelfHandlingForm):
     name = forms.CharField(label=_("Name"), required=False)
-    admin_state = forms.BooleanField(label=_("Enable Admin State"),
-                                     required=False)
+    admin_state = forms.BooleanField(
+        label=_("Enable Admin State"),
+        required=False,
+        help_text=_("If checked, the network will be enabled."))
     shared = forms.BooleanField(label=_("Shared"), required=False)
     failure_url = 'horizon:project:networks:index'
 
     def __init__(self, request, *args, **kwargs):
-        super(UpdateNetwork, self).__init__(request, *args, **kwargs)
+        super().__init__(request, *args, **kwargs)
 
         if not policy.check((("network", "update_network:shared"),), request):
             self.fields['shared'].widget = forms.HiddenInput()
@@ -57,12 +59,14 @@ class UpdateNetwork(forms.SelfHandlingForm):
             network = api.neutron.network_update(request,
                                                  self.initial['network_id'],
                                                  **params)
-            msg = _('Network %s was successfully updated.') % data['name']
+            msg = (_('Network %s was successfully updated.') %
+                   network.name_or_id)
             messages.success(request, msg)
             return network
         except Exception as e:
             LOG.info('Failed to update network %(id)s: %(exc)s',
                      {'id': self.initial['network_id'], 'exc': e})
-            msg = _('Failed to update network %s') % data['name']
+            name_or_id = data['name'] or self.initial['network_id']
+            msg = _('Failed to update network %s') % name_or_id
             redirect = reverse(self.failure_url)
             exceptions.handle(request, msg, redirect=redirect)
