@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -45,7 +45,7 @@ class AddRouterRouteView(forms.ModalFormView):
             exceptions.handle(self.request, msg, redirect=redirect)
 
     def get_context_data(self, **kwargs):
-        context = super(AddRouterRouteView, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         context['router'] = self.get_object()
         return context
 
